from helper import unittest, PillowTestCase, hopper
from PIL import Image


class TestFileWmf(PillowTestCase):

    def test_load_raw(self):

        # Test basic EMF open and rendering
        im = Image.open('Tests/images/drawing.emf')
        if hasattr(Image.core, "drawwmf"):
            # Currently, support for WMF/EMF is Windows-only
            im.load()
            # Compare to reference rendering
            imref = Image.open('Tests/images/drawing_emf_ref.png')
            imref.load()
            self.assert_image_similar(im, imref, 0)

        # Test basic WMF open and rendering
        im = Image.open('Tests/images/drawing.wmf')
        if hasattr(Image.core, "drawwmf"):
            # Currently, support for WMF/EMF is Windows-only
            im.load()
            # Compare to reference rendering
            imref = Image.open('Tests/images/drawing_wmf_ref.png')
            imref.load()
            self.assert_image_similar(im, imref, 2.0)

    def test_save(self):
        im = hopper()

        for ext in [".wmf", ".emf"]:
            tmpfile = self.tempfile("temp"+ext)
            self.assertRaises(IOError, lambda: im.save(tmpfile))


if __name__ == '__main__':
    unittest.main()



from helper import unittest, PillowTestCase, hopper

from PIL import Image, ImagePalette, MicImagePlugin

TEST_FILE = "Tests/images/hopper.mic"


class TestFileMic(PillowTestCase):

    def test_sanity(self):
        im = Image.open(TEST_FILE)
        im.load()
        self.assertEqual(im.mode, "RGBA")
        self.assertEqual(im.size, (128, 128))
        self.assertEqual(im.format, "MIC")

        # Adjust for the gamma of 2.2 encoded into the file
        lut = ImagePalette.make_gamma_lut(1/2.2)
        im = Image.merge('RGBA', [chan.point(lut) for chan in im.split()])

        im2 = hopper("RGBA")
        self.assert_image_similar(im, im2, 10)

    def test_n_frames(self):
        im = Image.open(TEST_FILE)

        self.assertEqual(im.n_frames, 1)

    def test_is_animated(self):
        im = Image.open(TEST_FILE)

        self.assertFalse(im.is_animated)

    def test_tell(self):
        im = Image.open(TEST_FILE)

        self.assertEqual(im.tell(), 0)

    def test_seek(self):
        im = Image.open(TEST_FILE)

        im.seek(0)
        self.assertEqual(im.tell(), 0)

        self.assertRaises(EOFError, lambda: im.seek(99))
        self.assertEqual(im.tell(), 0)

    def test_invalid_file(self):
        # Test an invalid OLE file
        invalid_file = "Tests/images/flower.jpg"
        self.assertRaises(SyntaxError,
                          lambda: MicImagePlugin.MicImageFile(invalid_file))

        # Test a valid OLE file, but not a MIC file
        ole_file = "Tests/images/test-ole-file.doc"
        self.assertRaises(SyntaxError,
                          lambda: MicImagePlugin.MicImageFile(ole_file))


if __name__ == '__main__':
    unittest.main()



from helper import unittest, PillowTestCase, hopper

from PIL import Image, ImImagePlugin

# sample im
TEST_IM = "Tests/images/hopper.im"


class TestFileIm(PillowTestCase):

    def test_sanity(self):
        im = Image.open(TEST_IM)
        im.load()
        self.assertEqual(im.mode, "RGB")
        self.assertEqual(im.size, (128, 128))
        self.assertEqual(im.format, "IM")

    def test_n_frames(self):
        im = Image.open(TEST_IM)
        self.assertEqual(im.n_frames, 1)
        self.assertFalse(im.is_animated)

    def test_eoferror(self):
        im = Image.open(TEST_IM)

        n_frames = im.n_frames
        while True:
            n_frames -= 1
            try:
                im.seek(n_frames)
                break
            except EOFError:
                self.assertLess(im.tell(), n_frames)

    def test_roundtrip(self):
        out = self.tempfile('temp.im')
        im = hopper()
        im.save(out)
        reread = Image.open(out)

        self.assert_image_equal(reread, im)

    def test_invalid_file(self):
        invalid_file = "Tests/images/flower.jpg"

        self.assertRaises(SyntaxError,
                          lambda: ImImagePlugin.ImImageFile(invalid_file))


if __name__ == '__main__':
    unittest.main()



from helper import unittest, PillowTestCase

from PIL.GimpPaletteFile import GimpPaletteFile


class TestImage(PillowTestCase):

    def test_sanity(self):
        with open('Tests/images/test.gpl', 'rb') as fp:
            GimpPaletteFile(fp)

        with open('Tests/images/hopper.jpg', 'rb') as fp:
            self.assertRaises(SyntaxError, lambda: GimpPaletteFile(fp))

        with open('Tests/images/bad_palette_file.gpl', 'rb') as fp:
            self.assertRaises(SyntaxError, lambda: GimpPaletteFile(fp))

        with open('Tests/images/bad_palette_entry.gpl', 'rb') as fp:
            self.assertRaises(ValueError, lambda: GimpPaletteFile(fp))

    def test_get_palette(self):
        # Arrange
        with open('Tests/images/custom_gimp_palette.gpl', 'rb') as fp:
            palette_file = GimpPaletteFile(fp)

        # Act
        palette, mode = palette_file.getpalette()

        # Assert
        self.assertEqual(mode, "RGB")


if __name__ == '__main__':
    unittest.main()
